@@ -1,5 +1,5 @@
 /*
- * Copyright 2017 Red Hat, Inc. and/or its affiliates.
+ * Copyright 2018 Red Hat, Inc. and/or its affiliates.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,12 +15,7 @@
  */
 package org.jbpm.workbench.pr.client.editors.instance.list;
 
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.Date;
-import java.util.List;
-import java.util.Random;
-import java.util.Set;
+import java.util.*;
 import java.util.function.Predicate;
 
 import com.google.common.collect.Lists;
@@ -50,6 +45,7 @@ import org.jbpm.workbench.df.client.filter.FilterSettingsManager;
 import org.jbpm.workbench.df.client.list.DataSetQueryHelper;
 import org.jbpm.workbench.pr.client.editors.instance.signal.ProcessInstanceSignalPresenter;
 import org.jbpm.workbench.pr.client.resources.i18n.Constants;
+import org.jbpm.workbench.pr.events.ProcessInstanceSelectionEvent;
 import org.jbpm.workbench.pr.model.ProcessInstanceSummary;
 import org.jbpm.workbench.pr.service.ProcessService;
 import org.junit.Before;
@@ -67,6 +63,7 @@ import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.ext.widgets.common.client.breadcrumbs.UberfireBreadcrumbs;
 import org.uberfire.mocks.CallerMock;
+import org.uberfire.mocks.EventSourceMock;
 import org.uberfire.mvp.Command;
 import org.uberfire.mvp.Commands;
 import org.uberfire.mvp.PlaceRequest;
@@ -75,13 +72,16 @@ import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.workbench.model.ActivityResourceType;
 
 import static java.util.Arrays.asList;
+import static java.util.Collections.singletonMap;
 import static org.dashbuilder.dataset.filter.FilterFactory.equalsTo;
 import static org.dashbuilder.dataset.filter.FilterFactory.likeTo;
-import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_DEFINITION_ID;
-import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_INSTANCE_ID;
+import static org.jbpm.workbench.common.client.PerspectiveIds.*;
 import static org.jbpm.workbench.pr.model.ProcessInstanceDataSetConstants.*;
 import static org.junit.Assert.*;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.*;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.EXECUTION_ERRORS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.JOBS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASKS;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.TASKS_ADMIN;
 import static org.mockito.Mockito.*;
 
 @RunWith(GwtMockitoTestRunner.class)
@@ -149,6 +149,9 @@ public class ProcessInstanceListPresenterTest {
     @Mock
     private FilterSettingsManager filterSettingsManager;
 
+    @Mock
+    EventSourceMock<ProcessInstanceSelectionEvent> processInstanceSelectionEvent = new EventSourceMock<>();
+
     @InjectMocks
     private ProcessInstanceListPresenter presenter;
 
@@ -290,56 +293,48 @@ public class ProcessInstanceListPresenterTest {
     @Test
     public void abortProcessInstancesTest() {
         final Random random = new Random();
-        final List<String> containers = new ArrayList<String>();
-        containers.add("container");
 
-        final List<Long> pIds = new ArrayList<Long>();
-        pIds.add(random.nextLong());
-        pIds.add(random.nextLong());
-        pIds.add(random.nextLong());
+        final Map<String, List<Long>> containerInstance = singletonMap("container",
+                                                                       Arrays.asList(random.nextLong(),
+                                                                                     random.nextLong(),
+                                                                                     random.nextLong()));
 
-        presenter.abortProcessInstances(containers,
-                                        pIds);
+        presenter.abortProcessInstances(containerInstance);
 
         verify(processService).abortProcessInstances(anyString(),
-                                                     eq(containers),
-                                                     eq(pIds));
+                                                     eq(containerInstance));
     }
 
     @Test
     public void bulkAbortProcessInstancesTest() {
-        final List<Long> pIds = new ArrayList<Long>();
-        final List<String> containers = new ArrayList<String>();
+        final Map<String, List<Long>> containerInstance = new HashMap<>();
         for (ProcessInstanceSummary summary : processInstanceSummaries) {
-            pIds.add(summary.getProcessInstanceId());
-            containers.add(summary.getDeploymentId());
+            containerInstance.computeIfAbsent(summary.getDeploymentId(),
+                                              key -> new ArrayList<>()).add(summary.getProcessInstanceId());
         }
 
         presenter.bulkAbort(processInstanceSummaries);
 
         verify(processService).abortProcessInstances(anyString(),
-                                                     eq(containers),
-                                                     eq(pIds));
+                                                     eq(containerInstance));
     }
 
     @Test
     public void bulkAbortProcessInstancesStateTest() {
         processInstanceSummaries.add(createProcessInstanceSummary(new Random().nextLong(),
                                                                   ProcessInstance.STATE_ABORTED));
-        final List<Long> pIds = new ArrayList<Long>();
-        final List<String> containers = new ArrayList<String>();
+        final Map<String, List<Long>> containerInstance = new HashMap<>();
         for (ProcessInstanceSummary summary : processInstanceSummaries) {
             if (summary.getState() == ProcessInstance.STATE_ACTIVE) {
-                pIds.add(summary.getProcessInstanceId());
-                containers.add(summary.getDeploymentId());
+                containerInstance.computeIfAbsent(summary.getDeploymentId(),
+                                                  key -> new ArrayList<>()).add(summary.getProcessInstanceId());
             }
         }
 
         presenter.bulkAbort(processInstanceSummaries);
 
         verify(processService).abortProcessInstances(anyString(),
-                                                     eq(containers),
-                                                     eq(pIds));
+                                                     eq(containerInstance));
     }
 
     @Test
@@ -556,7 +551,7 @@ public class ProcessInstanceListPresenterTest {
                      captor.getValue().getKey());
         assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active(),
                      captor.getValue().getLabelValue());
-        assertEquals(String.valueOf(ProcessInstance.STATE_ACTIVE),
+        assertEquals(ProcessInstance.STATE_ACTIVE,
                      (captor.getValue().getValue()));
     }
 
@@ -578,7 +573,7 @@ public class ProcessInstanceListPresenterTest {
                      captor.getValue().getKey());
         assertEquals(Constants.INSTANCE.State() + ": " + Constants.INSTANCE.Active(),
                      captor.getValue().getLabelValue());
-        assertEquals(String.valueOf(ProcessInstance.STATE_ACTIVE),
+        assertEquals(ProcessInstance.STATE_ACTIVE,
                      (captor.getValue().getValue()));
     }
 
@@ -626,7 +621,7 @@ public class ProcessInstanceListPresenterTest {
                      captor.getValue().getKey());
         assertEquals(Constants.INSTANCE.Id() + ": " + processInstanceId,
                      captor.getValue().getLabelValue());
-        assertEquals(processInstanceId,
+        assertEquals(1,
                      (captor.getValue().getValue()));
     }
 
@@ -850,4 +845,31 @@ public class ProcessInstanceListPresenterTest {
         verify(filterSettings).removeColumnFilter(columnFilter);
     }
 
+    @Test
+    public void testSelectProcessInstance() {
+        presenter.setProcessInstanceSelectedEvent(processInstanceSelectionEvent);
+
+        ProcessInstanceSummary okProcInst = new ProcessInstanceSummary();
+        presenter.selectSummaryItem(okProcInst);
+
+        ArgumentCaptor<ProcessInstanceSelectionEvent> argument = ArgumentCaptor.forClass(ProcessInstanceSelectionEvent.class);
+        verify(processInstanceSelectionEvent).fire(argument.capture());
+        verify(placeManager).goTo(PROCESS_INSTANCE_DETAILS_SCREEN);
+        verify(viewMock,
+               never()).displayNotification(anyString());
+    }
+
+    @Test
+    public void testFilterInitiator(){
+        String variableNameWithInitiator = "initiator";
+        String variableValueWithInitiator = "initiator people";
+
+        String variableNameWithoutInitiator = "noinitiator";
+        String variableValueWithoutInitiator = "other people";
+
+        assertEquals(true, presenter.filterInitiator(variableNameWithInitiator, variableValueWithInitiator, variableValueWithInitiator));
+        assertEquals(false, presenter.filterInitiator(variableNameWithoutInitiator, variableValueWithoutInitiator, variableValueWithoutInitiator));
+        assertEquals(false, presenter.filterInitiator(variableNameWithInitiator, variableValueWithInitiator, variableValueWithoutInitiator));
+        assertEquals(false, presenter.filterInitiator(variableNameWithoutInitiator, variableValueWithoutInitiator, variableValueWithInitiator));
+    }
 }
